Processor.App.OutStreamer.stream_to_file.OutStreamerFileJSON — CommonCrawl Extractor 1.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Processor.App.OutStreamer.stream_to_file.OutStreamerFileJSON

class Processor.App.OutStreamer.stream_to_file.OutStreamerFileJSON(origin: Path, extension: str = '.json', pretty: bool = False, **kwargs: Any)
  __init__(origin: Path, extension: str = '.json', pretty: bool = False, **kwargs: Any)

  Methods

  `__init__`(origin[, extension, pretty]) |
  `clean_up`() |
  `get_file_name`(metadata) |
  `metadata_to_string`(extracted_data) |
  `stream`(extracted_data, metadata) |